---
name: Request a new metric, statistical test, or tool
about: Suggest a new metric, statistical test, or tool which could be added to the repository

---

**I would like the following metric, statistical test or data processing tool to be considered for addition to the `scores` repository**  
Please briefly describe the metric, statistical test, or tool and why you think it would be useful.

**Please provide a reference that describes the metric, statistical test or data processing tool**  
Note: if the reference includes multiple versions of the metric, and you are interested in a specific version, please note that (e.g. specify which theorem or corollary). 

**(Please delete this section if not applicable) I intend to submit a pull request for the new metric, statistical test or data processing tool**
- [ ] Please read the [Contributing Guide](https://scores.readthedocs.io/en/develop/contributing.html#contributing-guide)
- [ ] Please read the [pull request checklist](https://github.com/nci/scores/blob/develop/.github/pull_request_template.md)
- [ ] I understand that, due to practical constraints, it may not always be possible for a metric, statistical test, or tool to be added
